==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebSelectHeaderDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDropdownHeaderDescriptionMetadata } from "./WebDropdownHeaderDescriptionMetadata";
import { WebSelectHeaderDescription } from "./WebSelectHeaderDescription";
/**
 * @hidden
 */
var WebSelectHeaderDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebSelectHeaderDescriptionMetadata, _super);
    function WebSelectHeaderDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebSelectHeaderDescriptionMetadata.b = function (a) {
        if (WebSelectHeaderDescriptionMetadata.a == null) {
            WebSelectHeaderDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebSelectHeaderDescriptionMetadata.c(WebSelectHeaderDescriptionMetadata.a);
        }
        if (a.k(WebSelectHeaderDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebSelectHeaderDescriptionMetadata.a);
    };
    WebSelectHeaderDescriptionMetadata.c = function (a) {
        WebDropdownHeaderDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:SelectHeader");
        a.item("__tagNameWC", "String:igc-select-header");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
    };
    WebSelectHeaderDescriptionMetadata.d = function (a) {
        WebSelectHeaderDescriptionMetadata.b(a);
        a.ac("WebSelectHeader", function () { return new WebSelectHeaderDescription(); });
        a.ab("WebSelectHeader", WebSelectHeaderDescriptionMetadata.a);
    };
    WebSelectHeaderDescriptionMetadata.$t = markType(WebSelectHeaderDescriptionMetadata, 'WebSelectHeaderDescriptionMetadata');
    WebSelectHeaderDescriptionMetadata.a = null;
    return WebSelectHeaderDescriptionMetadata;
}(Base));
export { WebSelectHeaderDescriptionMetadata };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/WebSelectHeaderDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSelectHeaderDescription } from "./WebSelectHeaderDescription";
/**
 * @hidden
 */
var WebSelectHeaderDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebSelectHeaderDescriptionMetadata, _super);
    function WebSelectHeaderDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebSelectHeaderDescriptionMetadata.b = function (a) {
        if (WebSelectHeaderDescriptionMetadata.a == null) {
            WebSelectHeaderDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebSelectHeaderDescriptionMetadata.c(WebSelectHeaderDescriptionMetadata.a);
        }
        if (a.k(WebSelectHeaderDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebSelectHeaderDescriptionMetadata.a);
    };
    WebSelectHeaderDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:SelectHeader");
        a.item("__tagNameWC", "String:igc-select-header");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
    };
    WebSelectHeaderDescriptionMetadata.d = function (a) {
        WebSelectHeaderDescriptionMetadata.b(a);
        a.ae("WebSelectHeader", function () { return new WebSelectHeaderDescription(); });
        a.ad("WebSelectHeader", WebSelectHeaderDescriptionMetadata.a);
    };
    WebSelectHeaderDescriptionMetadata.$t = markType(WebSelectHeaderDescriptionMetadata, 'WebSelectHeaderDescriptionMetadata');
    WebSelectHeaderDescriptionMetadata.a = null;
    return WebSelectHeaderDescriptionMetadata;
}(Base));
export { WebSelectHeaderDescriptionMetadata };
